# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Subscription(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'bundle_id': 'str',
        'bundle_external_key': 'str',
        'subscription_id': 'str',
        'external_key': 'str',
        'start_date': 'date',
        'product_name': 'str',
        'product_category': 'str',
        'billing_period': 'str',
        'phase_type': 'str',
        'price_list': 'str',
        'plan_name': 'str',
        'state': 'str',
        'source_type': 'str',
        'cancelled_date': 'date',
        'charged_through_date': 'date',
        'billing_start_date': 'date',
        'billing_end_date': 'date',
        'bill_cycle_day_local': 'int',
        'events': 'list[EventSubscription]',
        'price_overrides': 'list[PhasePrice]',
        'prices': 'list[PhasePrice]',
        'audit_logs': 'list[AuditLog]'
    }

    attribute_map = {
        'account_id': 'accountId',
        'bundle_id': 'bundleId',
        'bundle_external_key': 'bundleExternalKey',
        'subscription_id': 'subscriptionId',
        'external_key': 'externalKey',
        'start_date': 'startDate',
        'product_name': 'productName',
        'product_category': 'productCategory',
        'billing_period': 'billingPeriod',
        'phase_type': 'phaseType',
        'price_list': 'priceList',
        'plan_name': 'planName',
        'state': 'state',
        'source_type': 'sourceType',
        'cancelled_date': 'cancelledDate',
        'charged_through_date': 'chargedThroughDate',
        'billing_start_date': 'billingStartDate',
        'billing_end_date': 'billingEndDate',
        'bill_cycle_day_local': 'billCycleDayLocal',
        'events': 'events',
        'price_overrides': 'priceOverrides',
        'prices': 'prices',
        'audit_logs': 'auditLogs'
    }

    def __init__(self, account_id=None, bundle_id=None, bundle_external_key=None, subscription_id=None, external_key=None, start_date=None, product_name=None, product_category=None, billing_period=None, phase_type=None, price_list=None, plan_name=None, state=None, source_type=None, cancelled_date=None, charged_through_date=None, billing_start_date=None, billing_end_date=None, bill_cycle_day_local=None, events=None, price_overrides=None, prices=None, audit_logs=None):  # noqa: E501
        """Subscription - a model defined in Swagger"""  # noqa: E501
        self._account_id = None
        self._bundle_id = None
        self._bundle_external_key = None
        self._subscription_id = None
        self._external_key = None
        self._start_date = None
        self._product_name = None
        self._product_category = None
        self._billing_period = None
        self._phase_type = None
        self._price_list = None
        self._plan_name = None
        self._state = None
        self._source_type = None
        self._cancelled_date = None
        self._charged_through_date = None
        self._billing_start_date = None
        self._billing_end_date = None
        self._bill_cycle_day_local = None
        self._events = None
        self._price_overrides = None
        self._prices = None
        self._audit_logs = None
        self.discriminator = None
        if account_id is not None:
            self.account_id = account_id
        if bundle_id is not None:
            self.bundle_id = bundle_id
        if bundle_external_key is not None:
            self.bundle_external_key = bundle_external_key
        if subscription_id is not None:
            self.subscription_id = subscription_id
        if external_key is not None:
            self.external_key = external_key
        if start_date is not None:
            self.start_date = start_date
        self.product_name = product_name
        if product_category is not None:
            self.product_category = product_category
        self.billing_period = billing_period
        if phase_type is not None:
            self.phase_type = phase_type
        self.price_list = price_list
        self.plan_name = plan_name
        if state is not None:
            self.state = state
        if source_type is not None:
            self.source_type = source_type
        if cancelled_date is not None:
            self.cancelled_date = cancelled_date
        if charged_through_date is not None:
            self.charged_through_date = charged_through_date
        if billing_start_date is not None:
            self.billing_start_date = billing_start_date
        if billing_end_date is not None:
            self.billing_end_date = billing_end_date
        if bill_cycle_day_local is not None:
            self.bill_cycle_day_local = bill_cycle_day_local
        if events is not None:
            self.events = events
        if price_overrides is not None:
            self.price_overrides = price_overrides
        if prices is not None:
            self.prices = prices
        if audit_logs is not None:
            self.audit_logs = audit_logs

    @property
    def account_id(self):
        """Gets the account_id of this Subscription.  # noqa: E501


        :return: The account_id of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Subscription.


        :param account_id: The account_id of this Subscription.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def bundle_id(self):
        """Gets the bundle_id of this Subscription.  # noqa: E501


        :return: The bundle_id of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._bundle_id

    @bundle_id.setter
    def bundle_id(self, bundle_id):
        """Sets the bundle_id of this Subscription.


        :param bundle_id: The bundle_id of this Subscription.  # noqa: E501
        :type: str
        """

        self._bundle_id = bundle_id

    @property
    def bundle_external_key(self):
        """Gets the bundle_external_key of this Subscription.  # noqa: E501


        :return: The bundle_external_key of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._bundle_external_key

    @bundle_external_key.setter
    def bundle_external_key(self, bundle_external_key):
        """Sets the bundle_external_key of this Subscription.


        :param bundle_external_key: The bundle_external_key of this Subscription.  # noqa: E501
        :type: str
        """

        self._bundle_external_key = bundle_external_key

    @property
    def subscription_id(self):
        """Gets the subscription_id of this Subscription.  # noqa: E501


        :return: The subscription_id of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this Subscription.


        :param subscription_id: The subscription_id of this Subscription.  # noqa: E501
        :type: str
        """

        self._subscription_id = subscription_id

    @property
    def external_key(self):
        """Gets the external_key of this Subscription.  # noqa: E501


        :return: The external_key of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """Sets the external_key of this Subscription.


        :param external_key: The external_key of this Subscription.  # noqa: E501
        :type: str
        """

        self._external_key = external_key

    @property
    def start_date(self):
        """Gets the start_date of this Subscription.  # noqa: E501


        :return: The start_date of this Subscription.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Subscription.


        :param start_date: The start_date of this Subscription.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def product_name(self):
        """Gets the product_name of this Subscription.  # noqa: E501


        :return: The product_name of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """Sets the product_name of this Subscription.


        :param product_name: The product_name of this Subscription.  # noqa: E501
        :type: str
        """
        if product_name is None:
            raise ValueError("Invalid value for `product_name`, must not be `None`")  # noqa: E501

        self._product_name = product_name

    @property
    def product_category(self):
        """Gets the product_category of this Subscription.  # noqa: E501


        :return: The product_category of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._product_category

    @product_category.setter
    def product_category(self, product_category):
        """Sets the product_category of this Subscription.


        :param product_category: The product_category of this Subscription.  # noqa: E501
        :type: str
        """
        allowed_values = ["BASE", "ADD_ON", "STANDALONE"]  # noqa: E501
        if product_category not in allowed_values:
            raise ValueError(
                "Invalid value for `product_category` ({0}), must be one of {1}"  # noqa: E501
                .format(product_category, allowed_values)
            )

        self._product_category = product_category

    @property
    def billing_period(self):
        """Gets the billing_period of this Subscription.  # noqa: E501


        :return: The billing_period of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._billing_period

    @billing_period.setter
    def billing_period(self, billing_period):
        """Sets the billing_period of this Subscription.


        :param billing_period: The billing_period of this Subscription.  # noqa: E501
        :type: str
        """
        if billing_period is None:
            raise ValueError("Invalid value for `billing_period`, must not be `None`")  # noqa: E501
        allowed_values = ["DAILY", "WEEKLY", "BIWEEKLY", "THIRTY_DAYS", "SIXTY_DAYS", "NINETY_DAYS", "MONTHLY", "BIMESTRIAL", "QUARTERLY", "TRIANNUAL", "BIANNUAL", "ANNUAL", "BIENNIAL", "NO_BILLING_PERIOD"]  # noqa: E501
        if billing_period not in allowed_values:
            raise ValueError(
                "Invalid value for `billing_period` ({0}), must be one of {1}"  # noqa: E501
                .format(billing_period, allowed_values)
            )

        self._billing_period = billing_period

    @property
    def phase_type(self):
        """Gets the phase_type of this Subscription.  # noqa: E501


        :return: The phase_type of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._phase_type

    @phase_type.setter
    def phase_type(self, phase_type):
        """Sets the phase_type of this Subscription.


        :param phase_type: The phase_type of this Subscription.  # noqa: E501
        :type: str
        """
        allowed_values = ["TRIAL", "DISCOUNT", "FIXEDTERM", "EVERGREEN"]  # noqa: E501
        if phase_type not in allowed_values:
            raise ValueError(
                "Invalid value for `phase_type` ({0}), must be one of {1}"  # noqa: E501
                .format(phase_type, allowed_values)
            )

        self._phase_type = phase_type

    @property
    def price_list(self):
        """Gets the price_list of this Subscription.  # noqa: E501


        :return: The price_list of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._price_list

    @price_list.setter
    def price_list(self, price_list):
        """Sets the price_list of this Subscription.


        :param price_list: The price_list of this Subscription.  # noqa: E501
        :type: str
        """
        if price_list is None:
            raise ValueError("Invalid value for `price_list`, must not be `None`")  # noqa: E501

        self._price_list = price_list

    @property
    def plan_name(self):
        """Gets the plan_name of this Subscription.  # noqa: E501


        :return: The plan_name of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._plan_name

    @plan_name.setter
    def plan_name(self, plan_name):
        """Sets the plan_name of this Subscription.


        :param plan_name: The plan_name of this Subscription.  # noqa: E501
        :type: str
        """
        if plan_name is None:
            raise ValueError("Invalid value for `plan_name`, must not be `None`")  # noqa: E501

        self._plan_name = plan_name

    @property
    def state(self):
        """Gets the state of this Subscription.  # noqa: E501


        :return: The state of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Subscription.


        :param state: The state of this Subscription.  # noqa: E501
        :type: str
        """
        allowed_values = ["PENDING", "ACTIVE", "BLOCKED", "CANCELLED", "EXPIRED"]  # noqa: E501
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    @property
    def source_type(self):
        """Gets the source_type of this Subscription.  # noqa: E501


        :return: The source_type of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """Sets the source_type of this Subscription.


        :param source_type: The source_type of this Subscription.  # noqa: E501
        :type: str
        """
        allowed_values = ["NATIVE", "MIGRATED", "TRANSFERRED"]  # noqa: E501
        if source_type not in allowed_values:
            raise ValueError(
                "Invalid value for `source_type` ({0}), must be one of {1}"  # noqa: E501
                .format(source_type, allowed_values)
            )

        self._source_type = source_type

    @property
    def cancelled_date(self):
        """Gets the cancelled_date of this Subscription.  # noqa: E501


        :return: The cancelled_date of this Subscription.  # noqa: E501
        :rtype: date
        """
        return self._cancelled_date

    @cancelled_date.setter
    def cancelled_date(self, cancelled_date):
        """Sets the cancelled_date of this Subscription.


        :param cancelled_date: The cancelled_date of this Subscription.  # noqa: E501
        :type: date
        """

        self._cancelled_date = cancelled_date

    @property
    def charged_through_date(self):
        """Gets the charged_through_date of this Subscription.  # noqa: E501


        :return: The charged_through_date of this Subscription.  # noqa: E501
        :rtype: date
        """
        return self._charged_through_date

    @charged_through_date.setter
    def charged_through_date(self, charged_through_date):
        """Sets the charged_through_date of this Subscription.


        :param charged_through_date: The charged_through_date of this Subscription.  # noqa: E501
        :type: date
        """

        self._charged_through_date = charged_through_date

    @property
    def billing_start_date(self):
        """Gets the billing_start_date of this Subscription.  # noqa: E501


        :return: The billing_start_date of this Subscription.  # noqa: E501
        :rtype: date
        """
        return self._billing_start_date

    @billing_start_date.setter
    def billing_start_date(self, billing_start_date):
        """Sets the billing_start_date of this Subscription.


        :param billing_start_date: The billing_start_date of this Subscription.  # noqa: E501
        :type: date
        """

        self._billing_start_date = billing_start_date

    @property
    def billing_end_date(self):
        """Gets the billing_end_date of this Subscription.  # noqa: E501


        :return: The billing_end_date of this Subscription.  # noqa: E501
        :rtype: date
        """
        return self._billing_end_date

    @billing_end_date.setter
    def billing_end_date(self, billing_end_date):
        """Sets the billing_end_date of this Subscription.


        :param billing_end_date: The billing_end_date of this Subscription.  # noqa: E501
        :type: date
        """

        self._billing_end_date = billing_end_date

    @property
    def bill_cycle_day_local(self):
        """Gets the bill_cycle_day_local of this Subscription.  # noqa: E501


        :return: The bill_cycle_day_local of this Subscription.  # noqa: E501
        :rtype: int
        """
        return self._bill_cycle_day_local

    @bill_cycle_day_local.setter
    def bill_cycle_day_local(self, bill_cycle_day_local):
        """Sets the bill_cycle_day_local of this Subscription.


        :param bill_cycle_day_local: The bill_cycle_day_local of this Subscription.  # noqa: E501
        :type: int
        """

        self._bill_cycle_day_local = bill_cycle_day_local

    @property
    def events(self):
        """Gets the events of this Subscription.  # noqa: E501


        :return: The events of this Subscription.  # noqa: E501
        :rtype: list[EventSubscription]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this Subscription.


        :param events: The events of this Subscription.  # noqa: E501
        :type: list[EventSubscription]
        """

        self._events = events

    @property
    def price_overrides(self):
        """Gets the price_overrides of this Subscription.  # noqa: E501


        :return: The price_overrides of this Subscription.  # noqa: E501
        :rtype: list[PhasePrice]
        """
        return self._price_overrides

    @price_overrides.setter
    def price_overrides(self, price_overrides):
        """Sets the price_overrides of this Subscription.


        :param price_overrides: The price_overrides of this Subscription.  # noqa: E501
        :type: list[PhasePrice]
        """

        self._price_overrides = price_overrides

    @property
    def prices(self):
        """Gets the prices of this Subscription.  # noqa: E501


        :return: The prices of this Subscription.  # noqa: E501
        :rtype: list[PhasePrice]
        """
        return self._prices

    @prices.setter
    def prices(self, prices):
        """Sets the prices of this Subscription.


        :param prices: The prices of this Subscription.  # noqa: E501
        :type: list[PhasePrice]
        """

        self._prices = prices

    @property
    def audit_logs(self):
        """Gets the audit_logs of this Subscription.  # noqa: E501


        :return: The audit_logs of this Subscription.  # noqa: E501
        :rtype: list[AuditLog]
        """
        return self._audit_logs

    @audit_logs.setter
    def audit_logs(self, audit_logs):
        """Sets the audit_logs of this Subscription.


        :param audit_logs: The audit_logs of this Subscription.  # noqa: E501
        :type: list[AuditLog]
        """

        self._audit_logs = audit_logs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Subscription, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Subscription):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from killbill.api_client import ApiClient


class CreditApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_credits(self, body, x_killbill_created_by, **kwargs):  # noqa: E501
        """Create a credit  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_credits(body, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[InvoiceItem] body: (required)
        :param str x_killbill_created_by: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :param bool auto_commit:
        :param list[str] plugin_property:
        :return: list[InvoiceItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_credits_with_http_info(body, x_killbill_created_by, **kwargs)  # noqa: E501
        else:
            (data) = self.create_credits_with_http_info(body, x_killbill_created_by, **kwargs)  # noqa: E501
            return data

    def create_credits_with_http_info(self, body, x_killbill_created_by, **kwargs):  # noqa: E501
        """Create a credit  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_credits_with_http_info(body, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[InvoiceItem] body: (required)
        :param str x_killbill_created_by: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :param bool auto_commit:
        :param list[str] plugin_property:
        :return: list[InvoiceItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_killbill_created_by', 'x_killbill_reason', 'x_killbill_comment', 'auto_commit', 'plugin_property']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_credits" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_credits`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `create_credits`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'auto_commit' in params:
            query_params.append(('autoCommit', params['auto_commit']))  # noqa: E501
        if 'plugin_property' in params:
            query_params.append(('pluginProperty', params['plugin_property']))  # noqa: E501
            collection_formats['pluginProperty'] = 'multi'  # noqa: E501

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/credits', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InvoiceItem]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_credit(self, credit_id, **kwargs):  # noqa: E501
        """Retrieve a credit by id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_credit(credit_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credit_id: (required)
        :return: InvoiceItem
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_credit_with_http_info(credit_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_credit_with_http_info(credit_id, **kwargs)  # noqa: E501
            return data

    def get_credit_with_http_info(self, credit_id, **kwargs):  # noqa: E501
        """Retrieve a credit by id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_credit_with_http_info(credit_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str credit_id: (required)
        :return: InvoiceItem
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['credit_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_credit" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'credit_id' is set
        if ('credit_id' not in params or
                params['credit_id'] is None):
            raise ValueError("Missing the required parameter `credit_id` when calling `get_credit`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'credit_id' in params:
            path_params['creditId'] = params['credit_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/credits/{creditId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InvoiceItem',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.payment_gateway_api import PaymentGatewayApi  # noqa: E501
from killbill.rest import ApiException


class TestPaymentGatewayApi(unittest.TestCase):
    """PaymentGatewayApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.payment_gateway_api.PaymentGatewayApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_build_combo_form_descriptor(self):
        """Test case for build_combo_form_descriptor

        Combo API to generate form data to redirect the customer to the gateway  # noqa: E501
        """
        pass

    def test_build_form_descriptor(self):
        """Test case for build_form_descriptor

        Generate form data to redirect the customer to the gateway  # noqa: E501
        """
        pass

    def test_process_notification(self):
        """Test case for process_notification

        Process a gateway notification  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.payment_api import PaymentApi  # noqa: E501
from killbill.rest import ApiException


class TestPaymentApi(unittest.TestCase):
    """PaymentApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.payment_api.PaymentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_scheduled_payment_transaction_by_external_key(self):
        """Test case for cancel_scheduled_payment_transaction_by_external_key

        Cancels a scheduled payment attempt retry  # noqa: E501
        """
        pass

    def test_cancel_scheduled_payment_transaction_by_id(self):
        """Test case for cancel_scheduled_payment_transaction_by_id

        Cancels a scheduled payment attempt retry  # noqa: E501
        """
        pass

    def test_capture_authorization(self):
        """Test case for capture_authorization

        Capture an existing authorization  # noqa: E501
        """
        pass

    def test_capture_authorization_by_external_key(self):
        """Test case for capture_authorization_by_external_key

        Capture an existing authorization  # noqa: E501
        """
        pass

    def test_chargeback_payment(self):
        """Test case for chargeback_payment

        Record a chargeback  # noqa: E501
        """
        pass

    def test_chargeback_payment_by_external_key(self):
        """Test case for chargeback_payment_by_external_key

        Record a chargeback  # noqa: E501
        """
        pass

    def test_chargeback_reversal_payment(self):
        """Test case for chargeback_reversal_payment

        Record a chargeback reversal  # noqa: E501
        """
        pass

    def test_chargeback_reversal_payment_by_external_key(self):
        """Test case for chargeback_reversal_payment_by_external_key

        Record a chargeback reversal  # noqa: E501
        """
        pass

    def test_complete_transaction(self):
        """Test case for complete_transaction

        Complete an existing transaction  # noqa: E501
        """
        pass

    def test_complete_transaction_by_external_key(self):
        """Test case for complete_transaction_by_external_key

        Complete an existing transaction  # noqa: E501
        """
        pass

    def test_create_combo_payment(self):
        """Test case for create_combo_payment

        Combo api to create a new payment transaction on a existing (or not) account   # noqa: E501
        """
        pass

    def test_create_payment_custom_fields(self):
        """Test case for create_payment_custom_fields

        Add custom fields to payment  # noqa: E501
        """
        pass

    def test_create_payment_tags(self):
        """Test case for create_payment_tags

        Add tags to payment payment  # noqa: E501
        """
        pass

    def test_delete_payment_custom_fields(self):
        """Test case for delete_payment_custom_fields

        Remove custom fields from payment payment  # noqa: E501
        """
        pass

    def test_delete_payment_tags(self):
        """Test case for delete_payment_tags

        Remove tags from payment payment  # noqa: E501
        """
        pass

    def test_get_payment(self):
        """Test case for get_payment

        Retrieve a payment by id  # noqa: E501
        """
        pass

    def test_get_payment_attempt_audit_logs_with_history(self):
        """Test case for get_payment_attempt_audit_logs_with_history

        Retrieve payment attempt audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_payment_audit_logs_with_history(self):
        """Test case for get_payment_audit_logs_with_history

        Retrieve payment audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_payment_by_external_key(self):
        """Test case for get_payment_by_external_key

        Retrieve a payment by external key  # noqa: E501
        """
        pass

    def test_get_payment_custom_fields(self):
        """Test case for get_payment_custom_fields

        Retrieve payment custom fields  # noqa: E501
        """
        pass

    def test_get_payment_tags(self):
        """Test case for get_payment_tags

        Retrieve payment payment tags  # noqa: E501
        """
        pass

    def test_get_payments(self):
        """Test case for get_payments

        Get payments  # noqa: E501
        """
        pass

    def test_modify_payment_custom_fields(self):
        """Test case for modify_payment_custom_fields

        Modify custom fields to payment  # noqa: E501
        """
        pass

    def test_refund_payment(self):
        """Test case for refund_payment

        Refund an existing payment  # noqa: E501
        """
        pass

    def test_refund_payment_by_external_key(self):
        """Test case for refund_payment_by_external_key

        Refund an existing payment  # noqa: E501
        """
        pass

    def test_search_payments(self):
        """Test case for search_payments

        Search payments  # noqa: E501
        """
        pass

    def test_void_payment(self):
        """Test case for void_payment

        Void an existing payment  # noqa: E501
        """
        pass

    def test_void_payment_by_external_key(self):
        """Test case for void_payment_by_external_key

        Void an existing payment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PluginInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bundle_symbolic_name': 'str',
        'plugin_key': 'str',
        'plugin_name': 'str',
        'version': 'str',
        'state': 'str',
        'is_selected_for_start': 'bool',
        'services': 'list[PluginServiceInfo]'
    }

    attribute_map = {
        'bundle_symbolic_name': 'bundleSymbolicName',
        'plugin_key': 'pluginKey',
        'plugin_name': 'pluginName',
        'version': 'version',
        'state': 'state',
        'is_selected_for_start': 'isSelectedForStart',
        'services': 'services'
    }

    def __init__(self, bundle_symbolic_name=None, plugin_key=None, plugin_name=None, version=None, state=None, is_selected_for_start=None, services=None):  # noqa: E501
        """PluginInfo - a model defined in Swagger"""  # noqa: E501
        self._bundle_symbolic_name = None
        self._plugin_key = None
        self._plugin_name = None
        self._version = None
        self._state = None
        self._is_selected_for_start = None
        self._services = None
        self.discriminator = None
        if bundle_symbolic_name is not None:
            self.bundle_symbolic_name = bundle_symbolic_name
        if plugin_key is not None:
            self.plugin_key = plugin_key
        if plugin_name is not None:
            self.plugin_name = plugin_name
        if version is not None:
            self.version = version
        if state is not None:
            self.state = state
        if is_selected_for_start is not None:
            self.is_selected_for_start = is_selected_for_start
        if services is not None:
            self.services = services

    @property
    def bundle_symbolic_name(self):
        """Gets the bundle_symbolic_name of this PluginInfo.  # noqa: E501


        :return: The bundle_symbolic_name of this PluginInfo.  # noqa: E501
        :rtype: str
        """
        return self._bundle_symbolic_name

    @bundle_symbolic_name.setter
    def bundle_symbolic_name(self, bundle_symbolic_name):
        """Sets the bundle_symbolic_name of this PluginInfo.


        :param bundle_symbolic_name: The bundle_symbolic_name of this PluginInfo.  # noqa: E501
        :type: str
        """

        self._bundle_symbolic_name = bundle_symbolic_name

    @property
    def plugin_key(self):
        """Gets the plugin_key of this PluginInfo.  # noqa: E501


        :return: The plugin_key of this PluginInfo.  # noqa: E501
        :rtype: str
        """
        return self._plugin_key

    @plugin_key.setter
    def plugin_key(self, plugin_key):
        """Sets the plugin_key of this PluginInfo.


        :param plugin_key: The plugin_key of this PluginInfo.  # noqa: E501
        :type: str
        """

        self._plugin_key = plugin_key

    @property
    def plugin_name(self):
        """Gets the plugin_name of this PluginInfo.  # noqa: E501


        :return: The plugin_name of this PluginInfo.  # noqa: E501
        :rtype: str
        """
        return self._plugin_name

    @plugin_name.setter
    def plugin_name(self, plugin_name):
        """Sets the plugin_name of this PluginInfo.


        :param plugin_name: The plugin_name of this PluginInfo.  # noqa: E501
        :type: str
        """

        self._plugin_name = plugin_name

    @property
    def version(self):
        """Gets the version of this PluginInfo.  # noqa: E501


        :return: The version of this PluginInfo.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PluginInfo.


        :param version: The version of this PluginInfo.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def state(self):
        """Gets the state of this PluginInfo.  # noqa: E501


        :return: The state of this PluginInfo.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PluginInfo.


        :param state: The state of this PluginInfo.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def is_selected_for_start(self):
        """Gets the is_selected_for_start of this PluginInfo.  # noqa: E501


        :return: The is_selected_for_start of this PluginInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_selected_for_start

    @is_selected_for_start.setter
    def is_selected_for_start(self, is_selected_for_start):
        """Sets the is_selected_for_start of this PluginInfo.


        :param is_selected_for_start: The is_selected_for_start of this PluginInfo.  # noqa: E501
        :type: bool
        """

        self._is_selected_for_start = is_selected_for_start

    @property
    def services(self):
        """Gets the services of this PluginInfo.  # noqa: E501


        :return: The services of this PluginInfo.  # noqa: E501
        :rtype: list[PluginServiceInfo]
        """
        return self._services

    @services.setter
    def services(self, services):
        """Sets the services of this PluginInfo.


        :param services: The services of this PluginInfo.  # noqa: E501
        :type: list[PluginServiceInfo]
        """

        self._services = services

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PluginInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PluginInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OverdueCondition(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'time_since_earliest_unpaid_invoice_equals_or_exceeds': 'Duration',
        'control_tag_inclusion': 'str',
        'control_tag_exclusion': 'str',
        'number_of_unpaid_invoices_equals_or_exceeds': 'int',
        'response_for_last_failed_payment': 'list[str]',
        'total_unpaid_invoice_balance_equals_or_exceeds': 'float'
    }

    attribute_map = {
        'time_since_earliest_unpaid_invoice_equals_or_exceeds': 'timeSinceEarliestUnpaidInvoiceEqualsOrExceeds',
        'control_tag_inclusion': 'controlTagInclusion',
        'control_tag_exclusion': 'controlTagExclusion',
        'number_of_unpaid_invoices_equals_or_exceeds': 'numberOfUnpaidInvoicesEqualsOrExceeds',
        'response_for_last_failed_payment': 'responseForLastFailedPayment',
        'total_unpaid_invoice_balance_equals_or_exceeds': 'totalUnpaidInvoiceBalanceEqualsOrExceeds'
    }

    def __init__(self, time_since_earliest_unpaid_invoice_equals_or_exceeds=None, control_tag_inclusion=None, control_tag_exclusion=None, number_of_unpaid_invoices_equals_or_exceeds=None, response_for_last_failed_payment=None, total_unpaid_invoice_balance_equals_or_exceeds=None):  # noqa: E501
        """OverdueCondition - a model defined in Swagger"""  # noqa: E501
        self._time_since_earliest_unpaid_invoice_equals_or_exceeds = None
        self._control_tag_inclusion = None
        self._control_tag_exclusion = None
        self._number_of_unpaid_invoices_equals_or_exceeds = None
        self._response_for_last_failed_payment = None
        self._total_unpaid_invoice_balance_equals_or_exceeds = None
        self.discriminator = None
        if time_since_earliest_unpaid_invoice_equals_or_exceeds is not None:
            self.time_since_earliest_unpaid_invoice_equals_or_exceeds = time_since_earliest_unpaid_invoice_equals_or_exceeds
        if control_tag_inclusion is not None:
            self.control_tag_inclusion = control_tag_inclusion
        if control_tag_exclusion is not None:
            self.control_tag_exclusion = control_tag_exclusion
        if number_of_unpaid_invoices_equals_or_exceeds is not None:
            self.number_of_unpaid_invoices_equals_or_exceeds = number_of_unpaid_invoices_equals_or_exceeds
        if response_for_last_failed_payment is not None:
            self.response_for_last_failed_payment = response_for_last_failed_payment
        if total_unpaid_invoice_balance_equals_or_exceeds is not None:
            self.total_unpaid_invoice_balance_equals_or_exceeds = total_unpaid_invoice_balance_equals_or_exceeds

    @property
    def time_since_earliest_unpaid_invoice_equals_or_exceeds(self):
        """Gets the time_since_earliest_unpaid_invoice_equals_or_exceeds of this OverdueCondition.  # noqa: E501


        :return: The time_since_earliest_unpaid_invoice_equals_or_exceeds of this OverdueCondition.  # noqa: E501
        :rtype: Duration
        """
        return self._time_since_earliest_unpaid_invoice_equals_or_exceeds

    @time_since_earliest_unpaid_invoice_equals_or_exceeds.setter
    def time_since_earliest_unpaid_invoice_equals_or_exceeds(self, time_since_earliest_unpaid_invoice_equals_or_exceeds):
        """Sets the time_since_earliest_unpaid_invoice_equals_or_exceeds of this OverdueCondition.


        :param time_since_earliest_unpaid_invoice_equals_or_exceeds: The time_since_earliest_unpaid_invoice_equals_or_exceeds of this OverdueCondition.  # noqa: E501
        :type: Duration
        """

        self._time_since_earliest_unpaid_invoice_equals_or_exceeds = time_since_earliest_unpaid_invoice_equals_or_exceeds

    @property
    def control_tag_inclusion(self):
        """Gets the control_tag_inclusion of this OverdueCondition.  # noqa: E501


        :return: The control_tag_inclusion of this OverdueCondition.  # noqa: E501
        :rtype: str
        """
        return self._control_tag_inclusion

    @control_tag_inclusion.setter
    def control_tag_inclusion(self, control_tag_inclusion):
        """Sets the control_tag_inclusion of this OverdueCondition.


        :param control_tag_inclusion: The control_tag_inclusion of this OverdueCondition.  # noqa: E501
        :type: str
        """
        allowed_values = ["AUTO_PAY_OFF", "AUTO_INVOICING_OFF", "OVERDUE_ENFORCEMENT_OFF", "WRITTEN_OFF", "MANUAL_PAY", "TEST", "PARTNER", "AUTO_INVOICING_DRAFT", "AUTO_INVOICING_REUSE_DRAFT"]  # noqa: E501
        if control_tag_inclusion not in allowed_values:
            raise ValueError(
                "Invalid value for `control_tag_inclusion` ({0}), must be one of {1}"  # noqa: E501
                .format(control_tag_inclusion, allowed_values)
            )

        self._control_tag_inclusion = control_tag_inclusion

    @property
    def control_tag_exclusion(self):
        """Gets the control_tag_exclusion of this OverdueCondition.  # noqa: E501


        :return: The control_tag_exclusion of this OverdueCondition.  # noqa: E501
        :rtype: str
        """
        return self._control_tag_exclusion

    @control_tag_exclusion.setter
    def control_tag_exclusion(self, control_tag_exclusion):
        """Sets the control_tag_exclusion of this OverdueCondition.


        :param control_tag_exclusion: The control_tag_exclusion of this OverdueCondition.  # noqa: E501
        :type: str
        """
        allowed_values = ["AUTO_PAY_OFF", "AUTO_INVOICING_OFF", "OVERDUE_ENFORCEMENT_OFF", "WRITTEN_OFF", "MANUAL_PAY", "TEST", "PARTNER", "AUTO_INVOICING_DRAFT", "AUTO_INVOICING_REUSE_DRAFT"]  # noqa: E501
        if control_tag_exclusion not in allowed_values:
            raise ValueError(
                "Invalid value for `control_tag_exclusion` ({0}), must be one of {1}"  # noqa: E501
                .format(control_tag_exclusion, allowed_values)
            )

        self._control_tag_exclusion = control_tag_exclusion

    @property
    def number_of_unpaid_invoices_equals_or_exceeds(self):
        """Gets the number_of_unpaid_invoices_equals_or_exceeds of this OverdueCondition.  # noqa: E501


        :return: The number_of_unpaid_invoices_equals_or_exceeds of this OverdueCondition.  # noqa: E501
        :rtype: int
        """
        return self._number_of_unpaid_invoices_equals_or_exceeds

    @number_of_unpaid_invoices_equals_or_exceeds.setter
    def number_of_unpaid_invoices_equals_or_exceeds(self, number_of_unpaid_invoices_equals_or_exceeds):
        """Sets the number_of_unpaid_invoices_equals_or_exceeds of this OverdueCondition.


        :param number_of_unpaid_invoices_equals_or_exceeds: The number_of_unpaid_invoices_equals_or_exceeds of this OverdueCondition.  # noqa: E501
        :type: int
        """

        self._number_of_unpaid_invoices_equals_or_exceeds = number_of_unpaid_invoices_equals_or_exceeds

    @property
    def response_for_last_failed_payment(self):
        """Gets the response_for_last_failed_payment of this OverdueCondition.  # noqa: E501


        :return: The response_for_last_failed_payment of this OverdueCondition.  # noqa: E501
        :rtype: list[str]
        """
        return self._response_for_last_failed_payment

    @response_for_last_failed_payment.setter
    def response_for_last_failed_payment(self, response_for_last_failed_payment):
        """Sets the response_for_last_failed_payment of this OverdueCondition.


        :param response_for_last_failed_payment: The response_for_last_failed_payment of this OverdueCondition.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["INVALID_CARD", "EXPIRED_CARD", "LOST_OR_STOLEN_CARD", "DO_NOT_HONOR", "INSUFFICIENT_FUNDS", "DECLINE", "PROCESSING_ERROR", "INVALID_AMOUNT", "DUPLICATE_TRANSACTION", "OTHER"]  # noqa: E501
        if not set(response_for_last_failed_payment).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `response_for_last_failed_payment` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(response_for_last_failed_payment) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._response_for_last_failed_payment = response_for_last_failed_payment

    @property
    def total_unpaid_invoice_balance_equals_or_exceeds(self):
        """Gets the total_unpaid_invoice_balance_equals_or_exceeds of this OverdueCondition.  # noqa: E501


        :return: The total_unpaid_invoice_balance_equals_or_exceeds of this OverdueCondition.  # noqa: E501
        :rtype: float
        """
        return self._total_unpaid_invoice_balance_equals_or_exceeds

    @total_unpaid_invoice_balance_equals_or_exceeds.setter
    def total_unpaid_invoice_balance_equals_or_exceeds(self, total_unpaid_invoice_balance_equals_or_exceeds):
        """Sets the total_unpaid_invoice_balance_equals_or_exceeds of this OverdueCondition.


        :param total_unpaid_invoice_balance_equals_or_exceeds: The total_unpaid_invoice_balance_equals_or_exceeds of this OverdueCondition.  # noqa: E501
        :type: float
        """

        self._total_unpaid_invoice_balance_equals_or_exceeds = total_unpaid_invoice_balance_equals_or_exceeds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OverdueCondition, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OverdueCondition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Catalog(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'effective_date': 'datetime',
        'currencies': 'list[str]',
        'units': 'list[Unit]',
        'products': 'list[Product]',
        'price_lists': 'list[PriceList]'
    }

    attribute_map = {
        'name': 'name',
        'effective_date': 'effectiveDate',
        'currencies': 'currencies',
        'units': 'units',
        'products': 'products',
        'price_lists': 'priceLists'
    }

    def __init__(self, name=None, effective_date=None, currencies=None, units=None, products=None, price_lists=None):  # noqa: E501
        """Catalog - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._effective_date = None
        self._currencies = None
        self._units = None
        self._products = None
        self._price_lists = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if effective_date is not None:
            self.effective_date = effective_date
        if currencies is not None:
            self.currencies = currencies
        if units is not None:
            self.units = units
        if products is not None:
            self.products = products
        if price_lists is not None:
            self.price_lists = price_lists

    @property
    def name(self):
        """Gets the name of this Catalog.  # noqa: E501


        :return: The name of this Catalog.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Catalog.


        :param name: The name of this Catalog.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def effective_date(self):
        """Gets the effective_date of this Catalog.  # noqa: E501


        :return: The effective_date of this Catalog.  # noqa: E501
        :rtype: datetime
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """Sets the effective_date of this Catalog.


        :param effective_date: The effective_date of this Catalog.  # noqa: E501
        :type: datetime
        """

        self._effective_date = effective_date

    @property
    def currencies(self):
        """Gets the currencies of this Catalog.  # noqa: E501


        :return: The currencies of this Catalog.  # noqa: E501
        :rtype: list[str]
        """
        return self._currencies

    @currencies.setter
    def currencies(self, currencies):
        """Sets the currencies of this Catalog.


        :param currencies: The currencies of this Catalog.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["AED", "AFN", "ALL", "AMD", "ANG", "AOA", "ARS", "AUD", "AWG", "AZN", "BAM", "BBD", "BDT", "BGN", "BHD", "BIF", "BMD", "BND", "BOB", "BRL", "BSD", "BTN", "BWP", "BYR", "BZD", "CAD", "CDF", "CHF", "CLP", "CNY", "COP", "CRC", "CUC", "CUP", "CVE", "CZK", "DJF", "DKK", "DOP", "DZD", "EGP", "ERN", "ETB", "EUR", "FJD", "FKP", "GBP", "GEL", "GGP", "GHS", "GIP", "GMD", "GNF", "GTQ", "GYD", "HKD", "HNL", "HRK", "HTG", "HUF", "IDR", "ILS", "IMP", "INR", "IQD", "IRR", "ISK", "JEP", "JMD", "JOD", "JPY", "KES", "KGS", "KHR", "KMF", "KPW", "KRW", "KWD", "KYD", "KZT", "LAK", "LBP", "LKR", "LRD", "LSL", "LTL", "LVL", "LYD", "MAD", "MDL", "MGA", "MKD", "MMK", "MNT", "MOP", "MRO", "MUR", "MVR", "MWK", "MXN", "MYR", "MZN", "NAD", "NGN", "NIO", "NOK", "NPR", "NZD", "OMR", "PAB", "PEN", "PGK", "PHP", "PKR", "PLN", "PYG", "QAR", "RON", "RSD", "RUB", "RWF", "SAR", "SBD", "SCR", "SDG", "SEK", "SGD", "SHP", "SLL", "SOS", "SPL", "SRD", "STD", "SVC", "SYP", "SZL", "THB", "TJS", "TMT", "TND", "TOP", "TRY", "TTD", "TVD", "TWD", "TZS", "UAH", "UGX", "USD", "UYU", "UZS", "VEF", "VND", "VUV", "WST", "XAF", "XCD", "XDR", "XOF", "XPF", "YER", "ZAR", "ZMW", "ZWD", "BTC"]  # noqa: E501
        if not set(currencies).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `currencies` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(currencies) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._currencies = currencies

    @property
    def units(self):
        """Gets the units of this Catalog.  # noqa: E501


        :return: The units of this Catalog.  # noqa: E501
        :rtype: list[Unit]
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this Catalog.


        :param units: The units of this Catalog.  # noqa: E501
        :type: list[Unit]
        """

        self._units = units

    @property
    def products(self):
        """Gets the products of this Catalog.  # noqa: E501


        :return: The products of this Catalog.  # noqa: E501
        :rtype: list[Product]
        """
        return self._products

    @products.setter
    def products(self, products):
        """Sets the products of this Catalog.


        :param products: The products of this Catalog.  # noqa: E501
        :type: list[Product]
        """

        self._products = products

    @property
    def price_lists(self):
        """Gets the price_lists of this Catalog.  # noqa: E501


        :return: The price_lists of this Catalog.  # noqa: E501
        :rtype: list[PriceList]
        """
        return self._price_lists

    @price_lists.setter
    def price_lists(self, price_lists):
        """Sets the price_lists of this Catalog.


        :param price_lists: The price_lists of this Catalog.  # noqa: E501
        :type: list[PriceList]
        """

        self._price_lists = price_lists

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Catalog, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Catalog):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.catalog_api import CatalogApi  # noqa: E501
from killbill.rest import ApiException


class TestCatalogApi(unittest.TestCase):
    """CatalogApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.catalog_api.CatalogApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_simple_plan(self):
        """Test case for add_simple_plan

        Add a simple plan entry in the current version of the catalog  # noqa: E501
        """
        pass

    def test_delete_catalog(self):
        """Test case for delete_catalog

        Delete all versions for a per tenant catalog  # noqa: E501
        """
        pass

    def test_get_available_addons(self):
        """Test case for get_available_addons

        Retrieve available add-ons for a given product  # noqa: E501
        """
        pass

    def test_get_available_base_plans(self):
        """Test case for get_available_base_plans

        Retrieve available base plans  # noqa: E501
        """
        pass

    def test_get_catalog_json(self):
        """Test case for get_catalog_json

        Retrieve the catalog as JSON  # noqa: E501
        """
        pass

    def test_get_catalog_versions(self):
        """Test case for get_catalog_versions

        Retrieve a list of catalog versions  # noqa: E501
        """
        pass

    def test_get_catalog_xml(self):
        """Test case for get_catalog_xml

        Retrieve the full catalog as XML  # noqa: E501
        """
        pass

    def test_get_phase_for_subscription_and_date(self):
        """Test case for get_phase_for_subscription_and_date

        Retrieve phase for a given subscription and date  # noqa: E501
        """
        pass

    def test_get_plan_for_subscription_and_date(self):
        """Test case for get_plan_for_subscription_and_date

        Retrieve plan for a given subscription and date  # noqa: E501
        """
        pass

    def test_get_price_list_for_subscription_and_date(self):
        """Test case for get_price_list_for_subscription_and_date

        Retrieve priceList for a given subscription and date  # noqa: E501
        """
        pass

    def test_get_product_for_subscription_and_date(self):
        """Test case for get_product_for_subscription_and_date

        Retrieve product for a given subscription and date  # noqa: E501
        """
        pass

    def test_upload_catalog_xml(self):
        """Test case for upload_catalog_xml

        Upload the full catalog as XML  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Product(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'name': 'str',
        'pretty_name': 'str',
        'plans': 'list[Plan]',
        'included': 'list[str]',
        'available': 'list[str]'
    }

    attribute_map = {
        'type': 'type',
        'name': 'name',
        'pretty_name': 'prettyName',
        'plans': 'plans',
        'included': 'included',
        'available': 'available'
    }

    def __init__(self, type=None, name=None, pretty_name=None, plans=None, included=None, available=None):  # noqa: E501
        """Product - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._name = None
        self._pretty_name = None
        self._plans = None
        self._included = None
        self._available = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if name is not None:
            self.name = name
        if pretty_name is not None:
            self.pretty_name = pretty_name
        if plans is not None:
            self.plans = plans
        if included is not None:
            self.included = included
        if available is not None:
            self.available = available

    @property
    def type(self):
        """Gets the type of this Product.  # noqa: E501


        :return: The type of this Product.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Product.


        :param type: The type of this Product.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def name(self):
        """Gets the name of this Product.  # noqa: E501


        :return: The name of this Product.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Product.


        :param name: The name of this Product.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def pretty_name(self):
        """Gets the pretty_name of this Product.  # noqa: E501


        :return: The pretty_name of this Product.  # noqa: E501
        :rtype: str
        """
        return self._pretty_name

    @pretty_name.setter
    def pretty_name(self, pretty_name):
        """Sets the pretty_name of this Product.


        :param pretty_name: The pretty_name of this Product.  # noqa: E501
        :type: str
        """

        self._pretty_name = pretty_name

    @property
    def plans(self):
        """Gets the plans of this Product.  # noqa: E501


        :return: The plans of this Product.  # noqa: E501
        :rtype: list[Plan]
        """
        return self._plans

    @plans.setter
    def plans(self, plans):
        """Sets the plans of this Product.


        :param plans: The plans of this Product.  # noqa: E501
        :type: list[Plan]
        """

        self._plans = plans

    @property
    def included(self):
        """Gets the included of this Product.  # noqa: E501


        :return: The included of this Product.  # noqa: E501
        :rtype: list[str]
        """
        return self._included

    @included.setter
    def included(self, included):
        """Sets the included of this Product.


        :param included: The included of this Product.  # noqa: E501
        :type: list[str]
        """

        self._included = included

    @property
    def available(self):
        """Gets the available of this Product.  # noqa: E501


        :return: The available of this Product.  # noqa: E501
        :rtype: list[str]
        """
        return self._available

    @available.setter
    def available(self, available):
        """Sets the available of this Product.


        :param available: The available of this Product.  # noqa: E501
        :type: list[str]
        """

        self._available = available

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Product, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Product):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EventSubscription(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'event_id': 'str',
        'billing_period': 'str',
        'effective_date': 'date',
        'plan': 'str',
        'product': 'str',
        'price_list': 'str',
        'event_type': 'str',
        'is_blocked_billing': 'bool',
        'is_blocked_entitlement': 'bool',
        'service_name': 'str',
        'service_state_name': 'str',
        'phase': 'str',
        'audit_logs': 'list[AuditLog]'
    }

    attribute_map = {
        'event_id': 'eventId',
        'billing_period': 'billingPeriod',
        'effective_date': 'effectiveDate',
        'plan': 'plan',
        'product': 'product',
        'price_list': 'priceList',
        'event_type': 'eventType',
        'is_blocked_billing': 'isBlockedBilling',
        'is_blocked_entitlement': 'isBlockedEntitlement',
        'service_name': 'serviceName',
        'service_state_name': 'serviceStateName',
        'phase': 'phase',
        'audit_logs': 'auditLogs'
    }

    def __init__(self, event_id=None, billing_period=None, effective_date=None, plan=None, product=None, price_list=None, event_type=None, is_blocked_billing=None, is_blocked_entitlement=None, service_name=None, service_state_name=None, phase=None, audit_logs=None):  # noqa: E501
        """EventSubscription - a model defined in Swagger"""  # noqa: E501
        self._event_id = None
        self._billing_period = None
        self._effective_date = None
        self._plan = None
        self._product = None
        self._price_list = None
        self._event_type = None
        self._is_blocked_billing = None
        self._is_blocked_entitlement = None
        self._service_name = None
        self._service_state_name = None
        self._phase = None
        self._audit_logs = None
        self.discriminator = None
        if event_id is not None:
            self.event_id = event_id
        if billing_period is not None:
            self.billing_period = billing_period
        if effective_date is not None:
            self.effective_date = effective_date
        if plan is not None:
            self.plan = plan
        if product is not None:
            self.product = product
        if price_list is not None:
            self.price_list = price_list
        if event_type is not None:
            self.event_type = event_type
        if is_blocked_billing is not None:
            self.is_blocked_billing = is_blocked_billing
        if is_blocked_entitlement is not None:
            self.is_blocked_entitlement = is_blocked_entitlement
        if service_name is not None:
            self.service_name = service_name
        if service_state_name is not None:
            self.service_state_name = service_state_name
        if phase is not None:
            self.phase = phase
        if audit_logs is not None:
            self.audit_logs = audit_logs

    @property
    def event_id(self):
        """Gets the event_id of this EventSubscription.  # noqa: E501


        :return: The event_id of this EventSubscription.  # noqa: E501
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this EventSubscription.


        :param event_id: The event_id of this EventSubscription.  # noqa: E501
        :type: str
        """

        self._event_id = event_id

    @property
    def billing_period(self):
        """Gets the billing_period of this EventSubscription.  # noqa: E501


        :return: The billing_period of this EventSubscription.  # noqa: E501
        :rtype: str
        """
        return self._billing_period

    @billing_period.setter
    def billing_period(self, billing_period):
        """Sets the billing_period of this EventSubscription.


        :param billing_period: The billing_period of this EventSubscription.  # noqa: E501
        :type: str
        """
        allowed_values = ["DAILY", "WEEKLY", "BIWEEKLY", "THIRTY_DAYS", "SIXTY_DAYS", "NINETY_DAYS", "MONTHLY", "BIMESTRIAL", "QUARTERLY", "TRIANNUAL", "BIANNUAL", "ANNUAL", "BIENNIAL", "NO_BILLING_PERIOD"]  # noqa: E501
        if billing_period not in allowed_values:
            raise ValueError(
                "Invalid value for `billing_period` ({0}), must be one of {1}"  # noqa: E501
                .format(billing_period, allowed_values)
            )

        self._billing_period = billing_period

    @property
    def effective_date(self):
        """Gets the effective_date of this EventSubscription.  # noqa: E501


        :return: The effective_date of this EventSubscription.  # noqa: E501
        :rtype: date
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """Sets the effective_date of this EventSubscription.


        :param effective_date: The effective_date of this EventSubscription.  # noqa: E501
        :type: date
        """

        self._effective_date = effective_date

    @property
    def plan(self):
        """Gets the plan of this EventSubscription.  # noqa: E501


        :return: The plan of this EventSubscription.  # noqa: E501
        :rtype: str
        """
        return self._plan

    @plan.setter
    def plan(self, plan):
        """Sets the plan of this EventSubscription.


        :param plan: The plan of this EventSubscription.  # noqa: E501
        :type: str
        """

        self._plan = plan

    @property
    def product(self):
        """Gets the product of this EventSubscription.  # noqa: E501


        :return: The product of this EventSubscription.  # noqa: E501
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this EventSubscription.


        :param product: The product of this EventSubscription.  # noqa: E501
        :type: str
        """

        self._product = product

    @property
    def price_list(self):
        """Gets the price_list of this EventSubscription.  # noqa: E501


        :return: The price_list of this EventSubscription.  # noqa: E501
        :rtype: str
        """
        return self._price_list

    @price_list.setter
    def price_list(self, price_list):
        """Sets the price_list of this EventSubscription.


        :param price_list: The price_list of this EventSubscription.  # noqa: E501
        :type: str
        """

        self._price_list = price_list

    @property
    def event_type(self):
        """Gets the event_type of this EventSubscription.  # noqa: E501


        :return: The event_type of this EventSubscription.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this EventSubscription.


        :param event_type: The event_type of this EventSubscription.  # noqa: E501
        :type: str
        """
        allowed_values = ["START_ENTITLEMENT", "START_BILLING", "PAUSE_ENTITLEMENT", "PAUSE_BILLING", "RESUME_ENTITLEMENT", "RESUME_BILLING", "PHASE", "CHANGE", "STOP_ENTITLEMENT", "STOP_BILLING", "SERVICE_STATE_CHANGE"]  # noqa: E501
        if event_type not in allowed_values:
            raise ValueError(
                "Invalid value for `event_type` ({0}), must be one of {1}"  # noqa: E501
                .format(event_type, allowed_values)
            )

        self._event_type = event_type

    @property
    def is_blocked_billing(self):
        """Gets the is_blocked_billing of this EventSubscription.  # noqa: E501


        :return: The is_blocked_billing of this EventSubscription.  # noqa: E501
        :rtype: bool
        """
        return self._is_blocked_billing

    @is_blocked_billing.setter
    def is_blocked_billing(self, is_blocked_billing):
        """Sets the is_blocked_billing of this EventSubscription.


        :param is_blocked_billing: The is_blocked_billing of this EventSubscription.  # noqa: E501
        :type: bool
        """

        self._is_blocked_billing = is_blocked_billing

    @property
    def is_blocked_entitlement(self):
        """Gets the is_blocked_entitlement of this EventSubscription.  # noqa: E501


        :return: The is_blocked_entitlement of this EventSubscription.  # noqa: E501
        :rtype: bool
        """
        return self._is_blocked_entitlement

    @is_blocked_entitlement.setter
    def is_blocked_entitlement(self, is_blocked_entitlement):
        """Sets the is_blocked_entitlement of this EventSubscription.


        :param is_blocked_entitlement: The is_blocked_entitlement of this EventSubscription.  # noqa: E501
        :type: bool
        """

        self._is_blocked_entitlement = is_blocked_entitlement

    @property
    def service_name(self):
        """Gets the service_name of this EventSubscription.  # noqa: E501


        :return: The service_name of this EventSubscription.  # noqa: E501
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """Sets the service_name of this EventSubscription.


        :param service_name: The service_name of this EventSubscription.  # noqa: E501
        :type: str
        """

        self._service_name = service_name

    @property
    def service_state_name(self):
        """Gets the service_state_name of this EventSubscription.  # noqa: E501


        :return: The service_state_name of this EventSubscription.  # noqa: E501
        :rtype: str
        """
        return self._service_state_name

    @service_state_name.setter
    def service_state_name(self, service_state_name):
        """Sets the service_state_name of this EventSubscription.


        :param service_state_name: The service_state_name of this EventSubscription.  # noqa: E501
        :type: str
        """

        self._service_state_name = service_state_name

    @property
    def phase(self):
        """Gets the phase of this EventSubscription.  # noqa: E501


        :return: The phase of this EventSubscription.  # noqa: E501
        :rtype: str
        """
        return self._phase

    @phase.setter
    def phase(self, phase):
        """Sets the phase of this EventSubscription.


        :param phase: The phase of this EventSubscription.  # noqa: E501
        :type: str
        """

        self._phase = phase

    @property
    def audit_logs(self):
        """Gets the audit_logs of this EventSubscription.  # noqa: E501


        :return: The audit_logs of this EventSubscription.  # noqa: E501
        :rtype: list[AuditLog]
        """
        return self._audit_logs

    @audit_logs.setter
    def audit_logs(self, audit_logs):
        """Sets the audit_logs of this EventSubscription.


        :param audit_logs: The audit_logs of this EventSubscription.  # noqa: E501
        :type: list[AuditLog]
        """

        self._audit_logs = audit_logs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EventSubscription, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventSubscription):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HostedPaymentPageFormDescriptor(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'kb_account_id': 'str',
        'form_method': 'str',
        'form_url': 'str',
        'form_fields': 'dict(str, object)',
        'properties': 'dict(str, object)',
        'audit_logs': 'list[AuditLog]'
    }

    attribute_map = {
        'kb_account_id': 'kbAccountId',
        'form_method': 'formMethod',
        'form_url': 'formUrl',
        'form_fields': 'formFields',
        'properties': 'properties',
        'audit_logs': 'auditLogs'
    }

    def __init__(self, kb_account_id=None, form_method=None, form_url=None, form_fields=None, properties=None, audit_logs=None):  # noqa: E501
        """HostedPaymentPageFormDescriptor - a model defined in Swagger"""  # noqa: E501
        self._kb_account_id = None
        self._form_method = None
        self._form_url = None
        self._form_fields = None
        self._properties = None
        self._audit_logs = None
        self.discriminator = None
        if kb_account_id is not None:
            self.kb_account_id = kb_account_id
        if form_method is not None:
            self.form_method = form_method
        if form_url is not None:
            self.form_url = form_url
        if form_fields is not None:
            self.form_fields = form_fields
        if properties is not None:
            self.properties = properties
        if audit_logs is not None:
            self.audit_logs = audit_logs

    @property
    def kb_account_id(self):
        """Gets the kb_account_id of this HostedPaymentPageFormDescriptor.  # noqa: E501


        :return: The kb_account_id of this HostedPaymentPageFormDescriptor.  # noqa: E501
        :rtype: str
        """
        return self._kb_account_id

    @kb_account_id.setter
    def kb_account_id(self, kb_account_id):
        """Sets the kb_account_id of this HostedPaymentPageFormDescriptor.


        :param kb_account_id: The kb_account_id of this HostedPaymentPageFormDescriptor.  # noqa: E501
        :type: str
        """

        self._kb_account_id = kb_account_id

    @property
    def form_method(self):
        """Gets the form_method of this HostedPaymentPageFormDescriptor.  # noqa: E501


        :return: The form_method of this HostedPaymentPageFormDescriptor.  # noqa: E501
        :rtype: str
        """
        return self._form_method

    @form_method.setter
    def form_method(self, form_method):
        """Sets the form_method of this HostedPaymentPageFormDescriptor.


        :param form_method: The form_method of this HostedPaymentPageFormDescriptor.  # noqa: E501
        :type: str
        """

        self._form_method = form_method

    @property
    def form_url(self):
        """Gets the form_url of this HostedPaymentPageFormDescriptor.  # noqa: E501


        :return: The form_url of this HostedPaymentPageFormDescriptor.  # noqa: E501
        :rtype: str
        """
        return self._form_url

    @form_url.setter
    def form_url(self, form_url):
        """Sets the form_url of this HostedPaymentPageFormDescriptor.


        :param form_url: The form_url of this HostedPaymentPageFormDescriptor.  # noqa: E501
        :type: str
        """

        self._form_url = form_url

    @property
    def form_fields(self):
        """Gets the form_fields of this HostedPaymentPageFormDescriptor.  # noqa: E501


        :return: The form_fields of this HostedPaymentPageFormDescriptor.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._form_fields

    @form_fields.setter
    def form_fields(self, form_fields):
        """Sets the form_fields of this HostedPaymentPageFormDescriptor.


        :param form_fields: The form_fields of this HostedPaymentPageFormDescriptor.  # noqa: E501
        :type: dict(str, object)
        """

        self._form_fields = form_fields

    @property
    def properties(self):
        """Gets the properties of this HostedPaymentPageFormDescriptor.  # noqa: E501


        :return: The properties of this HostedPaymentPageFormDescriptor.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this HostedPaymentPageFormDescriptor.


        :param properties: The properties of this HostedPaymentPageFormDescriptor.  # noqa: E501
        :type: dict(str, object)
        """

        self._properties = properties

    @property
    def audit_logs(self):
        """Gets the audit_logs of this HostedPaymentPageFormDescriptor.  # noqa: E501


        :return: The audit_logs of this HostedPaymentPageFormDescriptor.  # noqa: E501
        :rtype: list[AuditLog]
        """
        return self._audit_logs

    @audit_logs.setter
    def audit_logs(self, audit_logs):
        """Sets the audit_logs of this HostedPaymentPageFormDescriptor.


        :param audit_logs: The audit_logs of this HostedPaymentPageFormDescriptor.  # noqa: E501
        :type: list[AuditLog]
        """

        self._audit_logs = audit_logs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HostedPaymentPageFormDescriptor, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HostedPaymentPageFormDescriptor):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
